<?php
namespace Teknisa\CADCTB\Factories;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Geral\Entities\Produto;
use Teknisa\Model\Geral\Entities\Prodfili;
use Teknisa\Model\Financeiro\Entities\Rattpctp;
use Teknisa\Model\Financeiro\Entities\Rattpajp;
use Teknisa\Model\Financeiro\Entities\Rattpctr;
use Teknisa\Model\Financeiro\Entities\Rattpajr;
use Teknisa\Model\Financeiro\Entities\Rattpdebi;
use Teknisa\Model\Financeiro\Entities\Rattpcred;

/**
 * Class Ger03500ParametrosCentroDeCustoFactory
 * @package Teknisa\CADCTB\Factories
 */
class Ger03500ParametrosCentroDeCustoFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
    }
    
    /**
     * Busca Rattpctp
     * @param $cdtpctpagar
     */
    public function buscaRattpctp($cdtpctpagar){
        /** @var $params */
        $params = array();
        $params['cdtpctpagar'] = $cdtpctpagar;

        /** @var Rattpctp $rattpctp */
        $rattpctp = $this->entityManager->getRepository(Rattpctp::class)->findBy($params);

        return $rattpctp;
    }
    
    /**
     * Busca Rattpajp
     * @param $cdajuctpag
     */
    public function buscaRattpajp($cdajuctpag){
        /** @var $params */
        $params = array();
        $params['cdajuctpag'] = $cdajuctpag;

        /** @var Rattpajp $rattpajp */
        $rattpajp = $this->entityManager->getRepository(Rattpajp::class)->findBy($params);

        return $rattpajp;
    }
    
    /**
     * Busca Rattpctr
     * @param $cdtpctreceb
     */
    public function buscaRattpctr($cdtpctreceb){
        /** @var $params */
        $params = array();
        $params['cdtpctreceb'] = $cdtpctreceb;

        /** @var Rattpctr $rattpctr */
        $rattpctr = $this->entityManager->getRepository(Rattpctr::class)->findBy($params);

        return $rattpctr;
    }
    
    /**
     * Busca Rattpajr
     * @param $cdajuctrec
     */
    public function buscaRattpajr($cdajuctrec){
        /** @var $params */
        $params = array();
        $params['cdajuctrec'] = $cdajuctrec;

        /** @var Rattpajr $rattpajr */
        $rattpajr = $this->entityManager->getRepository(Rattpajr::class)->findBy($params);

        return $rattpajr;
    }
    
    /**
     * Busca Rattpdebi
     * @param $cdtpdebibanc
     */
    public function buscaRattpdebi($cdtpdebibanc){
        /** @var $params */
        $params = array();
        $params['cdtpdebibanc'] = $cdtpdebibanc;

        /** @var Rattpdebi $rattpdebi */
        $rattpdebi = $this->entityManager->getRepository(Rattpdebi::class)->findBy($params);

        return $rattpdebi;
    }
    
    /**
     * Busca Rattpcred
     * @param $cdtpcredbanc
     */
    public function buscaRattpcred($cdtpcredbanc){
        /** @var $params */
        $params = array();
        $params['cdtpcredbanc'] = $cdtpcredbanc;

        /** @var Rattpcred $rattpcred */
        $rattpcred = $this->entityManager->getRepository(Rattpcred::class)->findBy($params);

        return $rattpcred;
    }
    
    /**
     * Busca Produto
     * @param $cdproduto
     */
    public function buscaProduto($cdproduto){
        /** @var $params */
        $params = array();
        $params['cdproduto'] = $cdproduto;

        /** @var Produto $produto */
        $produto = $this->entityManager->getRepository(Produto::class)->findOneBy($params);

        return $produto;
    }
    
    /**
     * Busca Produto por Filial
     * @param $cdproduto
     * @param $cdfilial
     */
    public function buscaProdfili($cdproduto, $cdfilial){
        /** @var $params */
        $params = array();
        $params['cdproduto'] = $cdproduto;
        $params['cdfilial']  = $cdfilial;

        /** @var Prodfili $prodfili */
        $prodfili = $this->entityManager->getRepository(Prodfili::class)->findOneBy($params);

        return $prodfili;
    }
    
    /**
     * Insere Rateio Tipo de Conta a Pagar
     * @param $nrorg
     * @param $cdtpctpagar
     * @param $cdcentcust
     * @param $vrperateio
     */
    public function insereRattpctp(
        $nrorg, $cdtpctpagar, $cdcentcust, $vrperateio
    ){
        /** @var Rattpctp $rattpctp */
        $rattpctp = new Rattpctp();
        $rattpctp->setNrorg($nrorg);
        $rattpctp->setCdtpctpagar($cdtpctpagar);
        $rattpctp->setCdcentcust($cdcentcust);
        $rattpctp->setVrperattpctp($vrperateio);
        $rattpctp->setCdfirattpctp('----');
        $rattpctp->setDtinclusao(DateUtil::getDataAtual());

        return $rattpctp;
    }
    
    /**
     * Insere Rateio Tipo de Ajuste de Conta a Pagar
     * @param $nrorg
     * @param $cdajuctpag
     * @param $cdcentcust
     * @param $vrperateio
     */
    public function insereRattpajp(
        $nrorg, $cdajuctpag, $cdcentcust, $vrperateio
    ){
        /** @var Rattpajp $rattpajp */
        $rattpajp = new Rattpajp();
        $rattpajp->setNrorg($nrorg);
        $rattpajp->setCdajuctpag($cdajuctpag);
        $rattpajp->setCdcentcust($cdcentcust);
        $rattpajp->setVrperattpajp($vrperateio);
        $rattpajp->setCdfirattpajp('----');
        $rattpajp->setDtinclusao(DateUtil::getDataAtual());

        return $rattpajp;
    }
    
    /**
     * Insere Rateio Tipo de Conta a Receber
     * @param $nrorg
     * @param $cdtpctreceb
     * @param $cdcentcust
     * @param $vrperateio
     */
    public function insereRattpctr(
        $nrorg, $cdtpctreceb, $cdcentcust, $vrperateio
    ){
        /** @var Rattpctr $rattpctr */
        $rattpctr = new Rattpctr();
        $rattpctr->setNrorg($nrorg);
        $rattpctr->setCdtpctreceb($cdtpctreceb);
        $rattpctr->setCdcentcust($cdcentcust);
        $rattpctr->setVrperattpctr($vrperateio);
        $rattpctr->setCdfirattpctr('----');
        $rattpctr->setDtinclusao(DateUtil::getDataAtual());

        return $rattpctr;
    }
    
    /**
     * Insere Rateio Tipo de Ajuste de Conta a Receber
     * @param $nrorg
     * @param $cdajuctrec
     * @param $cdcentcust
     * @param $vrperateio
     */
    public function insereRattpajr(
        $nrorg, $cdajuctrec, $cdcentcust, $vrperateio
    ){
        /** @var Rattpajr $rattpajr */
        $rattpajr = new Rattpajr();
        $rattpajr->setNrorg($nrorg);
        $rattpajr->setCdajuctrec($cdajuctrec);
        $rattpajr->setCdcentcust($cdcentcust);
        $rattpajr->setVrperattpajr($vrperateio);
        $rattpajr->setCdfirattpajr('----');
        $rattpajr->setDtinclusao(DateUtil::getDataAtual());

        return $rattpajr;
    }
    
    /**
     * Insere Rateio Tipo de Débito Bancário
     * @param $nrorg
     * @param $cdtpdebibanc
     * @param $cdcentcust
     * @param $vrperateio
     */
    public function insereRattpdebi(
        $nrorg, $cdtpdebibanc, $cdcentcust, $vrperateio
    ){
        /** @var Rattpdebi $rattpdebi */
        $rattpdebi = new Rattpdebi();
        $rattpdebi->setNrorg($nrorg);
        $rattpdebi->setCdtpdebibanc($cdtpdebibanc);
        $rattpdebi->setCdcentcust($cdcentcust);
        $rattpdebi->setVrperattpdeb($vrperateio);
        $rattpdebi->setCdfirattpdeb('----');
        $rattpdebi->setDtinclusao(DateUtil::getDataAtual());

        return $rattpdebi;
    }
    
    /**
     * Insere Rateio Tipo de Crédito Bancário
     * @param $nrorg
     * @param $cdtpcredbanc
     * @param $cdcentcust
     * @param $vrperateio
     */
    public function insereRattpcred(
        $nrorg, $cdtpcredbanc, $cdcentcust, $vrperateio
    ){
        /** @var Rattpdebi $rattpdebi */
        $rattpcred = new Rattpcred();
        $rattpcred->setNrorg($nrorg);
        $rattpcred->setCdtpcredbanc($cdtpcredbanc);
        $rattpcred->setCdcentcust($cdcentcust);
        $rattpcred->setVrperattpcre($vrperateio);
        $rattpcred->setCdfirattpcre('----');
        $rattpcred->setDtinclusao(DateUtil::getDataAtual());

        return $rattpcred;
    }
    
    /**
     * Busca Produtos
     * @param $cdarvprodini
     * @param $cdarvprodfin
     */
    public function buscaProdutos($cdarvprodini, $cdarvprodfin) {
        $params = array();
        $params['P_CDARVPRODINI'] = $cdarvprodini;
        $params['P_CDARVPRODFIN'] = $cdarvprodfin;
        
        $sql = "SELECT DISTINCT PR.CDPRODUTO
                FROM PRODUTO PR, PRODFILI PF
                WHERE PR.CDPRODUTO = PF.CDPRODUTO
                AND CDARVPROD BETWEEN :P_CDARVPRODINI AND :P_CDARVPRODFIN
                ORDER BY CDPRODUTO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca Produtos por Unidade
     * @param $cdarvprodini
     * @param $cdarvprodfin
     * @param $cdfilial
     */
    public function buscaProdfilis($cdarvprodini, $cdarvprodfin, $cdfilial) {
        $params = array();
        $params['P_CDARVPRODINI'] = $cdarvprodini;
        $params['P_CDARVPRODFIN'] = $cdarvprodfin;
        $params['P_CDFILIAL']     = $cdfilial;
        
        $sql = "SELECT PR.CDPRODUTO, PF.CDFILIAL
                FROM PRODUTO PR, PRODFILI PF
                WHERE PR.CDPRODUTO = PF.CDPRODUTO
                AND PR.CDARVPROD BETWEEN :P_CDARVPRODINI AND :P_CDARVPRODFIN
                AND PF.CDFILIAL = :P_CDFILIAL
                ORDER BY PR.CDARVPROD";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Atualiza Produto
     * @param $produto
     * @param $cdccustentr
     * @param $cdccustsaid
     */
    public function atualizaProduto(
        $produto, $cdccustentr, $cdccustsaid
    ){
        $produto->setCdccustentr($cdccustentr);
        $produto->setCdccustsaid($cdccustsaid);

        return $produto;
    }
    
    /**
     * Atualiza Produto por Filial
     * @param $produto
     * @param $cdccustentr
     * @param $cdccustsaid
     */
    public function atualizaProdfili(
        $prodfili, $cdccustentrf, $cdccustsaidf
    ){
        $prodfili->setCdccustentrf($cdccustentrf);
        $prodfili->setCdccustsaidf($cdccustsaidf);

        return $prodfili;
    }
}